import { readdir, readFile } from "fs/promises";
import path from "path";
import { join } from "./join";
import { RelativeFilePath } from "./RelativeFilePath";
export async function getDirectoryContents(absolutePath, options = {}) {
    const fileExtensionsWithPeriods = options.fileExtensions != null
        ? new Set(options.fileExtensions.map((fileExtension) => fileExtension.startsWith(".") ? fileExtension : `.${fileExtension}`))
        : undefined;
    const contents = [];
    const items = await readdir(absolutePath, { withFileTypes: true });
    await Promise.all(items.map(async (item) => {
        if (item.isDirectory()) {
            contents.push({
                type: "directory",
                name: item.name,
                contents: await getDirectoryContents(join(absolutePath, RelativeFilePath.of(item.name)), options),
            });
        }
        else if (fileExtensionsWithPeriods == null || fileExtensionsWithPeriods.has(path.extname(item.name))) {
            contents.push({
                type: "file",
                name: item.name,
                contents: (await readFile(path.join(absolutePath, item.name))).toString(),
            });
        }
    }));
    return contents.sort((a, b) => (a.name < b.name ? -1 : 1));
}
